==> google-cloud-spanner-3.0.0.tar.gz: google-cloud-spanner-3.0.0/google/cloud/spanner_admin_database_v1/types/__init__.py <==
# -*- coding: utf-8 -*-

# Copyright 2020 Google LLC
#
# Licensed under the Apache License, Version 2.0 (the "License");
# you may not use this file except in compliance with the License.
# You may obtain a copy of the License at
#
#     http://www.apache.org/licenses/LICENSE-2.0
#
# Unless required by applicable law or agreed to in writing, software
# distributed under the License is distributed on an "AS IS" BASIS,
# WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
# See the License for the specific language governing permissions and
# limitations under the License.
#

from .common import OperationProgress
from .backup import (
    Backup,
    CreateBackupRequest,
    CreateBackupMetadata,
    UpdateBackupRequest,
    GetBackupRequest,
    DeleteBackupRequest,
    ListBackupsRequest,
    ListBackupsResponse,
    ListBackupOperationsRequest,
    ListBackupOperationsResponse,
    BackupInfo,
)
from .spanner_database_admin import (
    RestoreInfo,
    Database,
    ListDatabasesRequest,
    ListDatabasesResponse,
    CreateDatabaseRequest,
    CreateDatabaseMetadata,
    GetDatabaseRequest,
    UpdateDatabaseDdlRequest,
    UpdateDatabaseDdlMetadata,
    DropDatabaseRequest,
    GetDatabaseDdlRequest,
    GetDatabaseDdlResponse,
    ListDatabaseOperationsRequest,
    ListDatabaseOperationsResponse,
    RestoreDatabaseRequest,
    RestoreDatabaseMetadata,
    OptimizeRestoredDatabaseMetadata,
    RestoreSourceType,
)

__all__ = (
    "OperationProgress",
    "Backup",
    "CreateBackupRequest",
    "CreateBackupMetadata",
    "UpdateBackupRequest",
    "GetBackupRequest",
    "DeleteBackupRequest",
    "ListBackupsRequest",
    "ListBackupsResponse",
    "ListBackupOperationsRequest",
    "ListBackupOperationsResponse",
    "BackupInfo",
    "RestoreInfo",
    "Database",
    "ListDatabasesRequest",
    "ListDatabasesResponse",
    "CreateDatabaseRequest",
    "CreateDatabaseMetadata",
    "GetDatabaseRequest",
    "UpdateDatabaseDdlRequest",
    "UpdateDatabaseDdlMetadata",
    "DropDatabaseRequest",
    "GetDatabaseDdlRequest",
    "GetDatabaseDdlResponse",
    "ListDatabaseOperationsRequest",
    "ListDatabaseOperationsResponse",
    "RestoreDatabaseRequest",
    "RestoreDatabaseMetadata",
    "OptimizeRestoredDatabaseMetadata",
    "RestoreSourceType",
)

==> google-cloud-spanner-3.9.0.tar.gz: google-cloud-spanner-3.9.0/google/cloud/spanner_admin_database_v1/types/__init__.py <==
# -*- coding: utf-8 -*-
# Copyright 2020 Google LLC
#
# Licensed under the Apache License, Version 2.0 (the "License");
# you may not use this file except in compliance with the License.
# You may obtain a copy of the License at
#
#     http://www.apache.org/licenses/LICENSE-2.0
#
# Unless required by applicable law or agreed to in writing, software
# distributed under the License is distributed on an "AS IS" BASIS,
# WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
# See the License for the specific language governing permissions and
# limitations under the License.
#
from .backup import (
    Backup,
    BackupInfo,
    CreateBackupEncryptionConfig,
    CreateBackupMetadata,
    CreateBackupRequest,
    DeleteBackupRequest,
    GetBackupRequest,
    ListBackupOperationsRequest,
    ListBackupOperationsResponse,
    ListBackupsRequest,
    ListBackupsResponse,
    UpdateBackupRequest,
)
from .common import (
    EncryptionConfig,
    EncryptionInfo,
    OperationProgress,
)
from .spanner_database_admin import (
    CreateDatabaseMetadata,
    CreateDatabaseRequest,
    Database,
    DropDatabaseRequest,
    GetDatabaseDdlRequest,
    GetDatabaseDdlResponse,
    GetDatabaseRequest,
    ListDatabaseOperationsRequest,
    ListDatabaseOperationsResponse,
    ListDatabasesRequest,
    ListDatabasesResponse,
    OptimizeRestoredDatabaseMetadata,
    RestoreDatabaseEncryptionConfig,
    RestoreDatabaseMetadata,
    RestoreDatabaseRequest,
    RestoreInfo,
    UpdateDatabaseDdlMetadata,
    UpdateDatabaseDdlRequest,
    RestoreSourceType,
)

__all__ = (
    "Backup",
    "BackupInfo",
    "CreateBackupEncryptionConfig",
    "CreateBackupMetadata",
    "CreateBackupRequest",
    "DeleteBackupRequest",
    "GetBackupRequest",
    "ListBackupOperationsRequest",
    "ListBackupOperationsResponse",
    "ListBackupsRequest",
    "ListBackupsResponse",
    "UpdateBackupRequest",
    "EncryptionConfig",
    "EncryptionInfo",
    "OperationProgress",
    "CreateDatabaseMetadata",
    "CreateDatabaseRequest",
    "Database",
    "DropDatabaseRequest",
    "GetDatabaseDdlRequest",
    "GetDatabaseDdlResponse",
    "GetDatabaseRequest",
    "ListDatabaseOperationsRequest",
    "ListDatabaseOperationsResponse",
    "ListDatabasesRequest",
    "ListDatabasesResponse",
    "OptimizeRestoredDatabaseMetadata",
    "RestoreDatabaseEncryptionConfig",
    "RestoreDatabaseMetadata",
    "RestoreDatabaseRequest",
    "RestoreInfo",
    "UpdateDatabaseDdlMetadata",
    "UpdateDatabaseDdlRequest",
    "RestoreSourceType",
)
